==> lucene4.10_4.10.4+dfsg.orig.tar.gz: lucene-4.10.4/queryparser/src/java/org/apache/lucene/queryparser/surround/query/RewriteQuery.java <==
package org.apache.lucene.queryparser.surround.query;
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import java.io.IOException;

import org.apache.lucene.index.IndexReader;
import org.apache.lucene.search.Query;

abstract class RewriteQuery<SQ extends SrndQuery> extends Query {
  protected final SQ srndQuery;
  protected final String fieldName;
  protected final BasicQueryFactory qf;

  RewriteQuery(
      SQ srndQuery,
      String fieldName,
      BasicQueryFactory qf) {
    this.srndQuery = srndQuery;
    this.fieldName = fieldName;
    this.qf = qf;
  }

  @Override
  abstract public Query rewrite(IndexReader reader) throws IOException;

  @Override
  public String toString() {
    return toString(null);
  }

  @Override
  public String toString(String field) {
    return getClass().getName()
    + (field == null ? "" : "(unused: " + field + ")")
    + "(" + fieldName
    + ", " + srndQuery.toString()
    + ", " + qf.toString()
    + ")";
  }

  @Override
  public int hashCode() {
    return getClass().hashCode()
    ^ fieldName.hashCode()
    ^ qf.hashCode()
    ^ srndQuery.hashCode();
  }

  @Override
  public boolean equals(Object obj) {
    if (obj == null)
      return false;
    if (! getClass().equals(obj.getClass()))
      return false;
    RewriteQuery other = (RewriteQuery)obj;
    return fieldName.equals(other.fieldName)
  && qf.equals(other.qf)
  && srndQuery.equals(other.srndQuery);
  }

  /** 
   * Not supported by this query.
   * @throws UnsupportedOperationException always: clone is not supported. */
  @Override
  public RewriteQuery clone() {
    throw new UnsupportedOperationException();
  }
}

==> lucene8_8.8.1.orig.tar.gz: lucene8-8.8.1/queryparser/src/java/org/apache/lucene/queryparser/surround/query/RewriteQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.lucene.queryparser.surround.query;
import java.io.IOException;
import java.util.Objects;

import org.apache.lucene.index.IndexReader;
import org.apache.lucene.search.Query;

abstract class RewriteQuery<SQ extends SrndQuery> extends Query {
  protected final SQ srndQuery;
  protected final String fieldName;
  protected final BasicQueryFactory qf;

  RewriteQuery(
      SQ srndQuery,
      String fieldName,
      BasicQueryFactory qf) {
    this.srndQuery = Objects.requireNonNull(srndQuery);
    this.fieldName = Objects.requireNonNull(fieldName);
    this.qf = Objects.requireNonNull(qf);
  }

  @Override
  abstract public Query rewrite(IndexReader reader) throws IOException;

  @Override
  public String toString(String field) {
    return getClass().getName()
    + (field.isEmpty() ? "" : "(unused: " + field + ")")
    + "(" + fieldName
    + ", " + srndQuery.toString()
    + ", " + qf.toString()
    + ")";
  }

  @Override
  public int hashCode() {
    return classHash()
      ^ fieldName.hashCode()
      ^ qf.hashCode()
      ^ srndQuery.hashCode();
  }

  @Override
  public boolean equals(Object other) {
    return sameClassAs(other) &&
           equalsTo(getClass().cast(other));
  }

  private boolean equalsTo(RewriteQuery<?> other) {
    return fieldName.equals(other.fieldName) && 
           qf.equals(other.qf) && 
           srndQuery.equals(other.srndQuery);
  }
}
